en_file_uploader library

file uploader package used to handle file upload.

follow README.md and FileUploadController to understand how this library can be used.

Classes

ChunkedFileUploadHandler
ChunkedFileUploadHandler handle the file upload split in chunks
FileChunk
Represents a chunk of the file.
FileUploadController
How to use
FileUploaderLogger
An abstract logger used inside the library to report info, warning and errors.
FileUploadHandler
FileUploadHandler handle the upload of an entire file
FileUploadPresentationResponse
The response of the file presentation.
FileUploadResult
the response of a file uploaded
FileUploadStatusResponse
The response of the file presentation.
IFileUploadHandler
The base class from which FileUploadHandler, ChunkedFileUploadHandler and RestorableChunkedFileUploadHandler were extended.
RestorableChunkedFileUploadHandler
RestorableChunkedFileUploadHandler handle the file upload in chunk with the capability to retry the upload from the last chunk sent. Follow the README.md to understand how this can be supported by the server side.
XFile
A CrossFile is a cross-platform, simplified File abstraction.

Properties

defaultChunkSize int
get the default chunk size. Can be set with setDefaultChunkSize
no setter

Functions

setDefaultChunkSize(int chunkSize) → void
to set the default chunk size used by ChunkedFileUploadHandler and RestorableChunkedFileUploadHandler

Typedefs

ProgressCallback = void Function(int count, int total)
progress callback

Exceptions / Errors

FileAlreadyUploadedException
file already uploaded exception
FileUploaderException
base class for file uploader exceptions
UnexpectedHandlerException
unexpected handler exception